@@ -1,12 +1,20 @@
 /**************************************************************************
-* This file is part of the WebIssues program
+* This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2009 WebIssues Team
+* Copyright (C) 2007-2011 WebIssues Team
 *
-* This program is free software; you can redistribute it and/or modify
+* This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
-* the Free Software Foundation; either version 2 of the License, or
+* the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
+*
+* This program is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+* GNU General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program.  If not, see <http://www.gnu.org/licenses/>.
 **************************************************************************/
 
 #ifndef COMMANDMANAGER_H
@@ -16,26 +24,19 @@
 #include <QUrl>
 #include <QList>
 
-class QHttp;
-class QHttpResponseHeader;
-class QNetworkProxy;
-
 #if defined( HAVE_OPENSSL )
-class QSslSocket;
-class QSslCertificate;
-class QSslCipher;
-class QSslError;
-#endif
-
-#if ( QT_VERSION >= 0x040300 )
-class QAuthenticator;
+#include <QSslConfiguration>
 #endif
 
 class AbstractBatch;
 class Command;
 class Reply;
 class ReplyLine;
-class CookieJar;
+class FormDataMessage;
+
+class QNetworkAccessManager;
+class QNetworkReply;
+class QAuthenticator;
 
 /**
 * Class for communicating with the WebIssues server.
@@ -59,14 +60,8 @@ public:
     {
         /** No error. */
         NoError,
-        /** The URL passed to the command manager is invalid. */
-        InvalidUrl,
-        /** The URL passed to the command manager has an unsupported scheme. */
-        UnknownUrlScheme,
-        /** Connection to the server failed. The errorCode() method returns a QHttp::Error flag. */
-        ConnectionError,
-        /** The server returned an HTTP error. The errorCode() method returns the HTTP status. */
-        HttpError,
+        /** Connection to the server failed. The errorCode() method returns a QNetworkReply::NetworkError flag. */
+        NetworkError,
         /** No WebIssues server was found at the given URL. */
         InvalidServer,
         /** The server version is not supported. */
@@ -79,26 +74,11 @@ public:
         Aborted
     };
 
-    /**
-    * Mode of connection with the server.
-    */
-    enum Mode
-    {
-        /** No URL or invalid URL specified. */
-        InvalidMode,
-        /** URL scheme not supported. */
-        UnknownMode,
-        /** Regular http connection. */
-        HttpMode,
-        /** Secure https connection. */
-        HttpsMode
-    };
-
 public:
     /**
-    * Default constructor.
+    * Constructor.
     */
-    CommandManager();
+    CommandManager( QNetworkAccessManager* manager );
 
     /**
     * Destructor.
@@ -108,7 +88,6 @@ public:
 public:
     /**
     * Set the URL of the server to send commands to.
-    *
     * @param url URL of the server.
     */
     void setServerUrl( const QUrl& url );
@@ -116,27 +95,18 @@ public:
     /**
     * Return the URL of the server.
     */
-    const QUrl& serverUrl() const { return m_url; }
-
-    /**
-    * Return the mode of connection with the server.
-    */
-    Mode connectionMode() const { return m_mode; }
+    QUrl serverUrl() const;
 
     /**
     * Append the batch to the execution queue.
-    *
     * The CommandManager takes ownership of the batch object.
-    *
     * @param batch Batch to execute.
     */
     void execute( AbstractBatch* batch );
 
     /**
     * Abort processing the batch and remove it from the execution queue.
-    *
     * The batch object is deleted immediately.
-    *
     * @param batch Batch to abort.
     */
     void abort( AbstractBatch* batch );
@@ -159,54 +129,20 @@ public:
     /**
     * Return full formatted error message;
     */
-    QString errorMessage( const QString& whatFailed );
-
-    /**
-    * Return the server version;
-    */
-    const QString& serverVersion() const { return m_serverVersion; }    
+    QString errorMessage();
 
 #if defined( HAVE_OPENSSL )
     /**
-    * Return server's chain of certificates.
+    * Return server's SSL configuration.
     */
-    QList<QSslCertificate> certificateChain();
-
-    /**
-    * Return the session's cryptographic cipher.
-    */
-    QSslCipher sessionCipher();
-
-    /**
-    * Set the list of SSL certificate digests for which errors are ignored.
-    */
-    void setAcceptedDigests( const QList<QByteArray>& digests );
-
-    /**
-    * Ignore SSL errors when called from the sslErrors() signal handler.
-    */
-    void ignoreSslErrors();
-#endif // defined( HAVE_OPENSSL )
-
-    /**
-    * Set proxy used to connect to the server.
-    */
-    void setProxy( const QNetworkProxy& proxy );
-
-signals:
-#if defined( HAVE_OPENSSL )
-    /**
-    * Forwards the sslErrors signal from the QSslSocket.
-    */
-    void sslErrors( const QList<QSslError>& );
+    QSslConfiguration sslConfiguration() const { return m_sslConfiguration; }
 #endif // defined( HAVE_OPENSSL )
 
 private:
     void sendSetHostRequest();
     void sendCommandRequest( Command* command );
 
-    bool handleCommandResponse( const QHttpResponseHeader& response );
-    bool handleCommandReply( const Reply& reply );
+    void handleCommandReply( const Reply& reply );
 
     bool parseReply( const QString& string, Reply& reply );
     bool validateReply( const Reply& reply );
@@ -218,47 +154,49 @@ private:
 
     void setError( Error error, int code = 0, const QString& string = QString() );
 
+    void handleAuthentication( int mode, const QString& hostName, QAuthenticator* authenticator );
+
+    QString networkError();
+    QString webIssuesError();
+
 private slots:
     void checkPendingCommand();
 
-    void dataSendProgress( int done, int total );
-    void dataReadProgress( int done, int total );
+    void metaDataChanged();
+    void readyRead();
 
-    void readyRead( const QHttpResponseHeader& response );
+    void finished( QNetworkReply* reply );
 
-    void requestFinished( int id, bool error );
+    void authenticationRequired( QNetworkReply* reply, QAuthenticator* authenticator );
+    void proxyAuthenticationRequired( const QNetworkProxy& proxy, QAuthenticator* authenticator );
 
 #if defined( HAVE_OPENSSL )
-    void handleSslErrors( const QList<QSslError>& errors );
+    void handleSslErrors( QNetworkReply* reply, const QList<QSslError>& errors );
 #endif // defined( HAVE_OPENSSL )
 
-#if ( QT_VERSION >= 0x040300 )
-    void authenticationRequired( const QString& hostname, quint16 port, QAuthenticator* authenticator );
-#endif
-
 private:
-    QHttp* m_http;
+    QNetworkAccessManager* m_manager;
 
 #if defined( HAVE_OPENSSL )
-    QSslSocket* m_sslSocket;
+    QList<QSslCertificate> m_certificates;
 
-    QList<QByteArray> m_acceptedDigests;
+    QSslConfiguration m_sslConfiguration;
 #endif
 
     QList<AbstractBatch*> m_batches;
 
-    Mode m_mode;
-
     QUrl m_url;
 
-    CookieJar* m_cookieJar;
-
-    int m_currentRequest;
     AbstractBatch* m_currentBatch;
     Command* m_currentCommand;
+    FormDataMessage* m_currentMessage;
+    QNetworkReply* m_currentReply;
+
+    int m_statusCode;
+    QUrl m_redirectionTarget;
+    QByteArray m_contentType;
 
     QString m_protocolVersion;
-    QString m_serverVersion;
 
     Error m_error;
     int m_errorCode;
