@@ -1,12 +1,20 @@
 /**************************************************************************
-* This file is part of the WebIssues program
+* This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2009 WebIssues Team
+* Copyright (C) 2007-2011 WebIssues Team
 *
-* This program is free software; you can redistribute it and/or modify
+* This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
-* the Free Software Foundation; either version 2 of the License, or
+* the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
+*
+* This program is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+* GNU General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program.  If not, see <http://www.gnu.org/licenses/>.
 **************************************************************************/
 
 #ifndef BOOKMARK_H
@@ -15,6 +23,8 @@
 #include <QString>
 #include <QMetaType>
 
+class QDataStream;
+
 /**
 * Structure storing information about a bookmark.
 */
@@ -29,8 +39,7 @@ public:
     /**
     * Constructor.
     */
-    Bookmark( const QString& serverName, const QString& serverUuid, const QString& url,
-        const QString& login, const QString& password );
+    Bookmark( const QString& serverName, const QString& serverUuid, const QString& url );
 
     /**
     * Destructor.
@@ -53,28 +62,14 @@ public:
     */
     const QString& url() const { return m_url; }
 
-    /**
-    * Set the URL of the server.
-    */
-    void setUrl( const QString& url ) { m_url = url; }
-
-    /**
-    * Return the login of the user.
-    */
-    const QString& login() const { return m_login; }
-
-    /**
-    * Return the password of the user.
-    */
-    const QString& password() const { return m_password; }
+public:
+    friend QDataStream& operator <<( QDataStream& stream, const Bookmark& bookmark );
+    friend QDataStream& operator >>( QDataStream& stream, Bookmark& bookmark );
 
 private:
     QString m_serverName;
     QString m_serverUuid;
-
     QString m_url;
-    QString m_login;
-    QString m_password;
 };
 
 Q_DECLARE_METATYPE( Bookmark )
