@@ -1,12 +1,20 @@
 /**************************************************************************
-* This file is part of the WebIssues program
+* This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2009 WebIssues Team
+* Copyright (C) 2007-2011 WebIssues Team
 *
-* This program is free software; you can redistribute it and/or modify
+* This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
-* the Free Software Foundation; either version 2 of the License, or
+* the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
+*
+* This program is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+* GNU General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program.  If not, see <http://www.gnu.org/licenses/>.
 **************************************************************************/
 
 #ifndef UPDATEEVENT_H
@@ -28,20 +36,24 @@ public:
     */
     enum Unit
     {
-        /** Users and their membership. */
+        /** Update server settings. */
+        Settings,
+        /** Update users and their membership. */
         Users,
-        /** Types and attributes. */
+        /** Update types, attributes and views. */
         Types,
-        /** Projects and folders. */
+        /** Update projects, folders and alerts. */
         Projects,
-        /** Issues in a given folder. */
+        /** Update states of all issues. */
+        States,
+        /** Update states of alerts. */
+        AlertStates,
+        /** Update issues and issue details in given folder. */
         Folder,
-        /** Details of a given issue. */
+        /** Update issues in given folder. */
+        IssueList,
+        /** Update details of given issue. */
         Issue,
-        /** User preferences. */
-        Preferences,
-        /** State of notifications. */
-        Notifications,
     };
 
     /**
@@ -52,9 +64,7 @@ public:
 public:
     /**
     * Constructor.
-    *
     * @param unit Unit of data which was updated.
-    *
     * @param id Identifier of the updated folder or issue.
     */
     UpdateEvent( Unit unit, int id );
