@@ -1,30 +1,49 @@
 /**************************************************************************
-* This file is part of the WebIssues program
+* This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2009 WebIssues Team
+* Copyright (C) 2007-2011 WebIssues Team
 *
-* This program is free software; you can redistribute it and/or modify
+* This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
-* the Free Software Foundation; either version 2 of the License, or
+* the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
+*
+* This program is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+* GNU General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program.  If not, see <http://www.gnu.org/licenses/>.
 **************************************************************************/
 
 #include "commanddialog.h"
 
+#include "commands/abstractbatch.h"
+#include "commands/commandmanager.h"
+#include "utils/errorhelper.h"
+#include "utils/iconloader.h"
+#include "widgets/inputlineedit.h"
+#include "widgets/inputtextedit.h"
+#include "widgets/elidedlabel.h"
+#include "xmlui/gradientwidget.h"
+
 #include <QLayout>
 #include <QLabel>
 #include <QProgressBar>
 #include <QDialogButtonBox>
 #include <QPushButton>
-
-#include "commands/abstractbatch.h"
-#include "commands/commandmanager.h"
-#include "widgets/gradientwidget.h"
-#include "iconloader.h"
+#include <QStackedWidget>
+#include <QTabWidget>
+#include <QScrollArea>
+#include <QMessageBox>
+#include <QAccessible>
 
 CommandDialog::CommandDialog( QWidget* parent ) : QDialog( parent ),
     m_promptPixmap( NULL ),
     m_contentLayout( NULL ),
+    m_fixed( false ),
+    m_statusSet( false ),
     m_progressBar( NULL ),
     m_progressLabel( NULL ),
     m_batch( NULL )
@@ -33,7 +52,7 @@ CommandDialog::CommandDialog( QWidget* parent ) : QDialog( parent ),
     topLayout->setMargin( 0 );
     topLayout->setSpacing( 0 );
 
-    m_promptWidget = new GradientWidget( this );
+    m_promptWidget = new XmlUi::GradientWidget( this );
     topLayout->addWidget( m_promptWidget );
 
     m_promptLayout = new QHBoxLayout( m_promptWidget );
@@ -58,7 +77,7 @@ CommandDialog::CommandDialog( QWidget* parent ) : QDialog( parent ),
     m_statusPixmap = new QLabel( this );
     statusLayout->addWidget( m_statusPixmap, 0 );
 
-    m_statusLabel = new QLabel( this );
+    m_statusLabel = new ElidedLabel( this );
     statusLayout->addWidget( m_statusLabel, 1 );
 
     m_buttonBox = new QDialogButtonBox( QDialogButtonBox::Ok | QDialogButtonBox::Cancel,
@@ -70,8 +89,6 @@ CommandDialog::CommandDialog( QWidget* parent ) : QDialog( parent ),
 
     connect( m_buttonBox, SIGNAL( accepted() ), this, SLOT( accept() ) );
     connect( m_buttonBox, SIGNAL( rejected() ), this, SLOT( reject() ) );
-
-    showInfo( tr( "Enter command arguments" ) );
 }
 
 CommandDialog::~CommandDialog()
@@ -108,8 +125,13 @@ void CommandDialog::setContentLayout( QLayout* layout, bool fixed )
         m_mainLayout->insertWidget( 1, separator );
     }
 
-    if ( fixed )
-        setMaximumHeight( sizeHint().height() );
+    if ( !m_statusSet )
+        showInfo( layout ? tr( "Please enter values." ) : tr( "Please confirm." ) );
+
+    if ( fixed ) {
+        m_fixed = true;
+        setFixedHeight( sizeHint().height() );
+    }
 }
 
 void CommandDialog::createProgressPanel( int total, const QString& text )
@@ -128,6 +150,9 @@ void CommandDialog::createProgressPanel( int total, const QString& text )
     m_mainLayout->insertWidget( 4, separator );
 
     m_progressText = text;
+
+    if ( m_fixed )
+        setFixedHeight( sizeHint().height() );
 }
 
 void CommandDialog::setProgress( int done, const QString& text )
@@ -140,12 +165,91 @@ void CommandDialog::showInfo( const QString& text )
 {
     m_statusPixmap->setPixmap( IconLoader::pixmap( "status-info" ) );
     m_statusLabel->setText( text );
+    m_statusSet = true;
 }
 
 void CommandDialog::showWarning( const QString& text )
 {
     m_statusPixmap->setPixmap( IconLoader::pixmap( "status-warning" ) );
     m_statusLabel->setText( text );
+    m_statusSet = true;
+
+    QMessageBox box;
+    box.setIcon( QMessageBox::Warning );
+    QAccessible::updateAccessibility( &box, 0, QAccessible::Alert );
+}
+
+void CommandDialog::showWarning( int code )
+{
+    ErrorHelper helper;
+    showWarning( helper.statusMessage( (ErrorHelper::ErrorCode)code ) );
+}
+
+void CommandDialog::showError( const QString& text )
+{
+    m_statusPixmap->setPixmap( IconLoader::pixmap( "status-error" ) );
+    m_statusLabel->setText( text );
+    m_statusSet = true;
+
+    QMessageBox box;
+    box.setIcon( QMessageBox::Critical );
+    QAccessible::updateAccessibility( &box, 0, QAccessible::Alert );
+}
+
+void CommandDialog::showCloseButton()
+{
+    m_buttonBox->button( QDialogButtonBox::Cancel )->setText( tr( "&Close" ) );
+    m_buttonBox->button( QDialogButtonBox::Ok )->hide();
+}
+
+bool CommandDialog::validate()
+{
+    bool result = true;
+    QWidget* errorWidget = NULL;
+
+    foreach ( InputLineEdit* edit, findChildren<InputLineEdit*>() ) {
+        if ( edit->isEnabled() && !edit->validate() ) {
+            if ( !errorWidget )
+                errorWidget = edit;
+            result = false;
+        }
+    }
+
+    foreach ( InputTextEdit* edit, findChildren<InputTextEdit*>() ) {
+        if ( edit->isEnabled() && !edit->validate() ) {
+            if ( !errorWidget )
+                errorWidget = edit;
+            result = false;
+        }
+    }
+
+    if ( !result )
+        showWarning( tr( "Some of the values you entered are incorrect." ) );
+
+    if ( errorWidget ) {
+        QWidget* widget = errorWidget;
+        QWidget* parent = widget->parentWidget();
+
+        while ( parent != this ) {
+            QStackedWidget* stackedWidget = qobject_cast<QStackedWidget*>( parent );
+            if ( stackedWidget ) {
+                QTabWidget* tabWidget = qobject_cast<QTabWidget*>( stackedWidget->parentWidget() );
+                if ( tabWidget )
+                    tabWidget->setCurrentWidget( widget );
+            }
+
+            QScrollArea* scrollArea = qobject_cast<QScrollArea*>( parent );
+            if ( scrollArea )
+                scrollArea->ensureWidgetVisible( errorWidget );
+
+            widget = parent;
+            parent = widget->parentWidget();
+        }
+
+        errorWidget->setFocus();
+    }
+
+    return result;
 }
 
 void CommandDialog::executeBatch( AbstractBatch* batch, const QString& text /* = QString() */ )
@@ -188,9 +292,9 @@ void CommandDialog::batchCompleted( bool successful )
             return;
         }
     } else {
-        showWarning( commandManager->errorMessage( tr( "Command could not be executed" ) ) );
+        showError( tr( "Command failed: %1." ).arg( commandManager->errorMessage() ) );
         if ( !batchFailed( m_batch ) ) {
-            m_buttonBox->button( QDialogButtonBox::Cancel )->setText( tr( "&Close" ) );
+            showCloseButton();
             m_batch = NULL;
             return;
         }
