@@ -1,12 +1,20 @@
 /**************************************************************************
-* This file is part of the WebIssues program
+* This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2009 WebIssues Team
+* Copyright (C) 2007-2011 WebIssues Team
 *
-* This program is free software; you can redistribute it and/or modify
+* This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
-* the Free Software Foundation; either version 2 of the License, or
+* the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
+*
+* This program is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+* GNU General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program.  If not, see <http://www.gnu.org/licenses/>.
 **************************************************************************/
 
 #ifndef COMMANDDIALOG_H
@@ -14,14 +22,15 @@
 
 #include <QDialog>
 
+class AbstractBatch;
+class ElidedLabel;
+
 class QLabel;
 class QBoxLayout;
 class QProgressBar;
 class QDialogButtonBox;
 class QLayoutItem;
 
-class AbstractBatch;
-
 /**
 * Base class for dialogs for executing commands.
 *
@@ -45,7 +54,6 @@ class CommandDialog : public QDialog
 public:
     /**
     * Conctructor.
-    *
     * @param parent The parent widget.
     */
     CommandDialog( QWidget* parent );
@@ -58,7 +66,6 @@ public:
 protected:
     /**
     * Set the prompt text.
-    *
     * The prompt text is displayed in the top part of the dialog. HTML tags
     * can be used.
     */
@@ -71,69 +78,88 @@ protected:
 
     /**
     * Initialize the dialog content.
-    *
     * @param layout The layout to insert into the dialog.
-    *
     * @param fixed If @c true, the dialog cannot be resized vertically.
     */
     void setContentLayout( QLayout* layout, bool fixed );
 
+    /**
+    * Return @c true if the dialog has fixed layout.
+    */
+    bool isFixed() const { return m_fixed; }
+
     /**
     * Add a progress panel beneath the main content.
-    *
     * @param total The total number of steps in the progress bar.
-    *
     * @param text The initial status text.
     */
     void createProgressPanel( int total, const QString& text );
 
     /**
     * Set the current progress.
-    *
     * @param done The number of completed steps in the progress bar.
-    *
     * @param text The status text.
     */
     void setProgress( int done, const QString& text );
 
     /**
     * Show a message with an information icon.
-    *
     * @param text The status message.
     */
     void showInfo( const QString& text );
 
     /**
     * Show a message with a warning icon.
-    *
     * @param text The warning text.
     */
     void showWarning( const QString& text );
 
+    /**
+    * Show a warning message based on the error code.
+    * @param code The error code.
+    */
+    void showWarning( int code );
+
+    /**
+    * Show a message with an error icon.
+    * @param text The warning text.
+    */
+    void showError( const QString& text );
+
+    /**
+    * Show Close button instead of OK and Cancel.
+    */
+    void showCloseButton();
+
+    /**
+    * Validate all input controls in the dialog.
+    * @return @c true if all controls have valid input.
+    */
+    bool validate();
+
     /**
     * Start executing the batch of commands.
-    *
     * @param batch The batch to execute.
-    *
     * @param text Optional message text.
     */
     void executeBatch( AbstractBatch* batch, const QString& text = QString() );
 
+    /**
+    * Return the dialog's button box.
+    */
+    QDialogButtonBox* buttonBox() const { return m_buttonBox; }
+
 protected:
     /**
     * Called when the batch is finished successfully.
-    *
     * @param batch The batch that has been executed.
-    *
     * @return @c true to close the dialog, @c false to cancel closing.
     */
     virtual bool batchSuccessful( AbstractBatch* batch );
 
     /**
     * Called when the batch failed.
-    *
     * @param batch The batch that has been executed.
-    *
     * @return @c true to restore original state, @c false to keep disabled.
     */
     virtual bool batchFailed( AbstractBatch* batch );
@@ -157,9 +183,12 @@ private:
     QBoxLayout* m_mainLayout;
 
     QLayout* m_contentLayout;
+    bool m_fixed;
 
     QLabel* m_statusPixmap;
-    QLabel* m_statusLabel;
+    ElidedLabel* m_statusLabel;
+
+    bool m_statusSet;
 
     QDialogButtonBox* m_buttonBox;
 
