@@ -1,37 +1,37 @@
 /**************************************************************************
-* This file is part of the WebIssues program
+* This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2009 WebIssues Team
+* Copyright (C) 2007-2011 WebIssues Team
 *
-* This program is free software; you can redistribute it and/or modify
+* This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
-* the Free Software Foundation; either version 2 of the License, or
+* the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
+*
+* This program is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+* GNU General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program.  If not, see <http://www.gnu.org/licenses/>.
 **************************************************************************/
 
 #ifndef MAINWINDOW_H
 #define MAINWINDOW_H
 
+#include "xmlui/client.h"
+
 #include <QMainWindow>
 #include <QSystemTrayIcon>
 
-#include "configdata.h"
-#include "xmlui/client.h"
-#include "data/bookmark.h"
-
-#if defined( HAVE_OPENSSL )
-class QSslError;
-#endif
-
-class StartPage;
+class StartView;
 class View;
 class ProjectsView;
-class DashboardView;
 class FolderView;
 class IssueView;
-class LoginBatch;
-class StatusBar;
 class PaneWidget;
+class StatusLabel;
 
 /**
 * The main window of the application.
@@ -65,22 +65,16 @@ public:
 public: // overrides
     QMenu* createPopupMenu();
 
-    StatusBar* statusBar() { return (StatusBar*)QMainWindow::statusBar(); }
-
 protected: // overrides
     void closeEvent( QCloseEvent* e );
 
     bool eventFilter( QObject* object, QEvent* e );
 
 private slots:
+    void connectionOpened();
+
     void quit();
-
-    void newConnection();
     void closeConnection();
-
-    void importSettings();
-    void exportSettings();
-
     void connectionInfo();
 
     void showUsers();
@@ -96,52 +90,38 @@ private slots:
     void configure();
     void settingsChanged();
 
-    void openConnection( const Bookmark& bookmark );
-    void editConnection( const Bookmark& bookmark );
-
-    void loginCompleted( bool successful );
-    void abortLogin();
-
     void trayIconActivated( QSystemTrayIcon::ActivationReason reason );
 
     void captionChanged( const QString& caption );
 
-    void toolBarCreated( QToolBar* toolBar );
     void builderReset();
 
-#if defined( HAVE_OPENSSL )
-    void sslErrors( const QList<QSslError>& errors );
-#endif
-
     void folderEnabledChanged( bool enabled );
     void issueEnabledChanged( bool enabled );
 
-    void selectedFolderChanged( int folderId );
-    void selectedWatchChanged( int folderId, const QString& filter );
-    void selectedFilterChanged( const QString& filter );
+    void selectionChanged( int folderId, int viewId );
     void selectedIssueChanged( int issueId );
+    void currentViewChanged( int viewId );
 
     void updateSelection();
 
+    void showStatus( const QPixmap& pixmap, const QString& text, int icon = 0 );
+    void showSummary( const QPixmap& pixmap, const QString& text );
+
 private:
-    void showLoginDialog( const Bookmark& bookmark, bool editable );
-
-    void initializeView();
-    void closeView( bool startPage );
-
     void showStartPage();
 
+    void restoreViewState();
+    void storeViewState();
+
     void updateActions( bool connected );
 
     void setActiveView( View* view );
 
 private:
-    XmlUi::Builder* m_builder;
-
-    StartPage* m_startPage;
+    StartView* m_startView;
 
     ProjectsView* m_view;
-    DashboardView* m_dashboard;
     FolderView* m_folderView;
     IssueView* m_issueView;
 
@@ -150,19 +130,18 @@ private:
     PaneWidget* m_folderPane;
     PaneWidget* m_issuePane;
 
-    WindowLayout m_layout;
+    StatusLabel* m_statusLabel;
+    StatusLabel* m_summaryLabel;
+    StatusLabel* m_encryptionLabel;
+    StatusLabel* m_userLabel;
 
     QSystemTrayIcon* m_trayIcon;
 
-    LoginBatch* m_batch;
-
-    Bookmark m_bookmark;
-
     QTimer* m_selectionTimer;
 
     int m_selectedFolderId;
-    QString m_selectedFilter;
     int m_selectedIssueId;
+    int m_currentViewId;
 
     bool m_supressFilter;
 };
