@@ -1,19 +1,29 @@
 /**************************************************************************
-* This file is part of the WebIssues program
+* This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2009 WebIssues Team
+* Copyright (C) 2007-2011 WebIssues Team
 *
-* This program is free software; you can redistribute it and/or modify
+* This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
-* the Free Software Foundation; either version 2 of the License, or
+* the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
+*
+* This program is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+* GNU General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program.  If not, see <http://www.gnu.org/licenses/>.
 **************************************************************************/
 
 #ifndef USERSVIEW_H
 #define USERSVIEW_H
 
-#include "view.h"
-#include "rdb/tableitemmodel.h"
+#include "views/view.h"
+
+class UsersModel;
+class FilterLabel;
 
 class QTreeView;
 class QModelIndex;
@@ -27,9 +37,7 @@ class UsersView : public View
 public:
     /**
     * Constructor.
-    *
     * @param parent The parent object.
-    *
     * @param parentWidget The parent widget of the view's main widget.
     */
     UsersView( QObject* parent, QWidget* parentWidget );
@@ -52,15 +60,16 @@ private slots:
     void changePassword();
     void userPreferences();
 
-    void contextMenu( const QPoint& pos );
-    void activated( const QModelIndex& index );
+    void filterChanged( int index );
 
-private:
-    QModelIndex selectedIndex();
+    void contextMenu( const QPoint& pos );
+    void doubleClicked( const QModelIndex& index );
 
 private:
     QTreeView* m_list;
-    RDB::TableItemModel* m_model;
+    UsersModel* m_model;
+
+    FilterLabel* m_filterLabel;
 
     int m_selectedUserId;
 
