@@ -1,25 +1,32 @@
 /**************************************************************************
-* This file is part of the WebIssues program
+* This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2009 WebIssues Team
+* Copyright (C) 2007-2011 WebIssues Team
 *
-* This program is free software; you can redistribute it and/or modify
+* This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
-* the Free Software Foundation; either version 2 of the License, or
+* the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
+*
+* This program is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+* GNU General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program.  If not, see <http://www.gnu.org/licenses/>.
 **************************************************************************/
 
 #ifndef VIEW_H
 #define VIEW_H
 
+#include "data/datamanager.h"
+#include "xmlui/client.h"
+
 #include <QWidget>
 
-#include "xmlui/client.h"
-#include "data/datarows.h"
-
 class UpdateEvent;
-class UpdateBatch;
-class ViewEvent;
+class AbstractBatch;
 
 /**
 * A view which can be embedded in a window.
@@ -45,8 +52,6 @@ class ViewEvent;
 * from the data manager. It also handles executing update batches.
 *
 * The ViewManager can be used to create and activate views.
-* It can also post ViewEvent events to all views of a given class
-* for communication between views.
 */
 class View : public QObject, public XmlUi::Client
 {
@@ -54,7 +59,6 @@ class View : public QObject, public XmlUi::Client
 public:
     /**
     * Constructor.
-    *
     * @param parent The parent object.
     */
     View( QObject* parent );
@@ -121,7 +125,6 @@ public:
 public:
     /**
     * Update after embedding in the container.
-    *
     * Override this method to perform initialization of the view.
     */
     virtual void initialUpdate();
@@ -138,18 +141,14 @@ public:
 
     /**
     * Switch between normal and administrator access.
-    *
     * Override this method to show or hide administrative actions.
     */
     virtual void updateAccess( Access access );
 
     /**
     * Ask the view if it can be closed.
-    *
     * Override this method to ask the user about unsaved changes.
-    *
     * The default implementation returns @c true.
-    *
     * @return @c true if the view can be closed, @c false otherwise.
     */
     virtual bool queryClose();
@@ -157,14 +156,12 @@ public:
 signals:
     /**
     * Emitted when the caption was changed.
-    *
     * @param text The new caption.
     */
     void captionChanged( const QString& text );
 
     /**
     * Emitted when the view was enabled or disabled.
-    *
     * @param enabled The state of the view.
     */
     void enabledChanged( bool enabled );
@@ -172,7 +169,7 @@ signals:
     /**
     * Emitted when the status was changed.
     */
-    void statusChanged( const QPixmap& pixmap, const QString& text );
+    void statusChanged( const QPixmap& pixmap, const QString& text, int icon = 0 );
 
     /**
     * Emitted when the summary was changed.
@@ -182,17 +179,14 @@ signals:
 protected:
     /**
     * Handle the UpdateEvent from the data manager.
-    *
     * @param e The update event.
     */
     virtual void updateEvent( UpdateEvent* e );
 
     /**
-    * Handle the ViewEvent from the view manager.
-    *
-    * @param e The view event.
+    * Handle an error when updating the view.
     */
-    virtual void viewEvent( ViewEvent* e );
+    virtual void updateFailed();
 
 protected:
     /**
@@ -212,10 +206,9 @@ protected:
 
     /**
     * Start executing the update batch.
-    *
     * @param batch The batch to execute.
     */
-    void executeUpdate( UpdateBatch* batch );
+    void executeUpdate( AbstractBatch* batch );
 
     /**
     * Return @c true if an update batch is being executed.
@@ -224,28 +217,30 @@ protected:
 
     /**
     * Display an information status message.
-    *
     * @param text The status message.
     */
     void showInfo( const QString& text );
 
     /**
     * Display a warning status message.
-    *
     * @param text The status message.
     */
     void showWarning( const QString& text );
 
+    /**
+    * Display an error status message.
+    * @param text The status message.
+    */
+    void showError( const QString& text );
+
     /**
     * Display a busy status message.
-    *
     * @param text The status message.
     */
     void showBusy( const QString& text );
 
     /**
     * Display a summary message.
-    *
     * @param pixmap The summary pixmap.
     * @param text The summary message.
     */
